@@ -11,7 +11,7 @@ use IO::Pipe;
 
 use Proc::Fork;
 
-our $VERSION = '2.00';
+our $VERSION = '2.01';
 
 # --------------------------------------------------
 
@@ -28,7 +28,7 @@ sub new
 sub run_script
 {
 	my($self, $script)	= @_;
-	my($cmd)			= "$^X $script";
+	my($cmd)			= "$^X -Ilib $script";
 
 	my(@stack);
 
